@@ -16,10 +16,28 @@ limitations under the License.
 
 """
 
+HTTP_METHODS = (
+    'CONNECT',
+    'DELETE',
+    'GET',
+    'HEAD',
+    'OPTIONS',
+    'POST',
+    'PUT',
+    'TRACE',
+    'PATCH'
+)
+
+DEFAULT_MEDIA_TYPE = 'application/json; charset=utf-8'
+
+
 # Hoist classes and functions into the falcon namespace
-from falcon.version import version
-from falcon.api import API, DEFAULT_MEDIA_TYPE
-from falcon.status_codes import *
-from falcon.exceptions import *
-from falcon.http_error import HTTPError
-from falcon.util import dt_to_http
+from .version import version  # NOQA
+from .api import API, DEFAULT_MEDIA_TYPE  # NOQA
+from .status_codes import *  # NOQA
+from .exceptions import *  # NOQA
+from .http_error import HTTPError  # NOQA
+from .util import dt_to_http  # NOQA
+from .hooks import before, after  # NOQA
+from .request import Request  # NOQA
+from .response import Response  # NOQA
\ No newline at end of file
