@@ -23,8 +23,7 @@ from .status_codes import HTTP_416
 from .api_helpers import *
 
 from .http_error import HTTPError
-
-DEFAULT_MEDIA_TYPE = 'application/json; charset=utf-8'
+from falcon import DEFAULT_MEDIA_TYPE
 
 
 class API(object):
@@ -35,13 +34,31 @@ class API(object):
 
     """
 
-    __slots__ = ('_media_type', '_routes')
+    __slots__ = ('_after', '_before', '_media_type', '_routes')
+
+    def __init__(self, media_type=DEFAULT_MEDIA_TYPE, before=None, after=None):
+        """Initialize a new Falcon API instances
+
+        Args:
+            media_type: Default media type to use as the value for the
+                Content-Type header on responses. (default 'application/json')
+            before: A global action hook (or list of hooks) to call before
+                each on_* responder, for all resources. Similar to the
+                'falcon.before' decorator, but applies to the entire API. When
+                more than one action function is given, they will be executed
+                in natural order (starting with the first in the list).
+            after: A global action hook (or list of hooks) to call after each
+                on_* responder, for all resources. Similar to the 'after'
+                decorator, but applies to the entire API.
+
+        """
 
-    def __init__(self, media_type=DEFAULT_MEDIA_TYPE):
-        """Initialize default values"""
         self._routes = []
         self._media_type = media_type
 
+        self._before = prepare_global_hooks(before)
+        self._after = prepare_global_hooks(after)
+
     def __call__(self, env, start_response):
         """WSGI "app" method
 
@@ -55,7 +72,7 @@ class API(object):
         """
 
         req = Request(env)
-        resp = Response(self._media_type)
+        resp = Response()
 
         responder, params = self._get_responder(req.path, req.method)
 
@@ -75,20 +92,27 @@ class API(object):
         #
         use_body = not should_ignore_body(resp.status, req.method)
         if use_body:
-            content_length = set_content_length(resp)
+            set_content_length(resp)
+            body = get_body(resp)
         else:
-            content_length = 0
+            # Default: return an empty body
+            body = []
 
-        set_content_type = ((content_length != 0) or
+        # Set content type if needed
+        use_content_type = (body or
+                            req.method == 'HEAD' or
                             resp.status == HTTP_416)
-        start_response(resp.status, resp._wsgi_headers(set_content_type))
 
-        # Return an iterable for the body, per the WSGI spec
-        if use_body:
-            return prepare_wsgi_content(resp)
+        if use_content_type:
+            media_type = self._media_type
+        else:
+            media_type = None
 
-        # Default: return an empty body
-        return []
+        headers = resp._wsgi_headers(media_type)
+
+        # Return the response per the WSGI spec
+        start_response(resp.status, headers)
+        return body
 
     def add_route(self, uri_template, resource):
         """Associate a URI path with a resource
@@ -105,12 +129,17 @@ class API(object):
         """
 
         path_template = compile_uri_template(uri_template)
-        method_map = create_http_method_map(resource)
+        method_map = create_http_method_map(resource,
+                                            self._before, self._after)
 
         # Insert at the head of the list in case we get duplicate
         # adds (will cause the last one to win).
         self._routes.insert(0, (path_template, method_map))
 
+#-----------------------------------------------------------------------------
+# Helpers
+#----------------------------------------------------------------------------
+
     def _get_responder(self, path, method):
         """Searches routes for a matching responder
 
