@@ -17,21 +17,12 @@ limitations under the License.
 """
 
 import re
+from functools import wraps
+
+from falcon import responders, HTTP_METHODS
 
-from falcon import responders
 import falcon.status_codes as status
 
-HTTP_METHODS = (
-    'CONNECT',
-    'DELETE',
-    'GET',
-    'HEAD',
-    'OPTIONS',
-    'POST',
-    'PUT',
-    'TRACE',
-    'PATCH'
-)
 
 IGNORE_BODY_STATUS_CODES = {
     status.HTTP_100,
@@ -42,6 +33,18 @@ IGNORE_BODY_STATUS_CODES = {
 }
 
 
+def prepare_global_hooks(hooks):
+    if hooks is not None:
+        if not isinstance(hooks, list):
+            hooks = [hooks]
+
+        for action in hooks:
+            if not hasattr(action, '__call__'):
+                raise TypeError('One or more hooks are not callable')
+
+    return hooks
+
+
 def should_ignore_body(status, method):
     """Return True if the status or method indicates no body, per RFC 2616
 
@@ -65,7 +68,7 @@ def set_content_length(resp):
     Post:
         resp contains a "Content-Length" header unless a stream is given, but
         resp.stream_len is not set (in which case, the length cannot be
-        derived reliably).
+            derived reliably).
     Args:
         resp: The response object on which to set the content length.
 
@@ -90,7 +93,7 @@ def set_content_length(resp):
     return content_length
 
 
-def prepare_wsgi_content(resp):
+def get_body(resp):
     """Converts resp content into an iterable as required by PEP 333
 
     Args:
@@ -149,7 +152,7 @@ def compile_uri_template(template=None):
     return re.compile(pattern, re.IGNORECASE)
 
 
-def create_http_method_map(resource):
+def create_http_method_map(resource, before, after):
     """Maps HTTP methods (such as GET and POST) to methods of resource object
 
     Args:
@@ -157,6 +160,8 @@ def create_http_method_map(resource):
            correspond to each method the resource supports. For example, if a
            resource supports GET and POST, it should define
            on_get(self, req, resp) and on_post(self,req,resp).
+        before: An action hooks or list of hooks to be called before each
+           on_* responder defined by the resource.
 
     """
 
@@ -164,21 +169,77 @@ def create_http_method_map(resource):
 
     for method in HTTP_METHODS:
         try:
-            func = getattr(resource, 'on_' + method.lower())
+            responder = getattr(resource, 'on_' + method.lower())
         except AttributeError:
             # resource does not implement this method
             pass
         else:
             # Usually expect a method, but any callable will do
-            if hasattr(func, '__call__'):
-                method_map[method] = func
+            if hasattr(responder, '__call__'):
+                responder = _wrap_with_hooks(before, after, responder)
+                method_map[method] = responder
 
     # Attach a resource for unsupported HTTP methods
     allowed_methods = list(method_map.keys())
-    func = responders.create_method_not_allowed(allowed_methods)
+    responder = responders.create_method_not_allowed(allowed_methods)
 
     for method in HTTP_METHODS:
         if method not in allowed_methods:
-            method_map[method] = func
+            method_map[method] = responder
 
     return method_map
+
+
+#-----------------------------------------------------------------------------
+# Helpers
+#-----------------------------------------------------------------------------
+
+
+def _wrap_with_hooks(before, after, responder):
+    if after is not None:
+        for action in after:
+            responder = _wrap_with_after(action, responder)
+
+    if before is not None:
+        # Wrap in reversed order to achieve natural (first...last)
+        # execution order.
+        for action in reversed(before):
+            responder = _wrap_with_before(action, responder)
+
+    return responder
+
+
+def _wrap_with_before(action, responder):
+    """Execute the given action function before a bound responder.
+
+    Args:
+        action: A function with a similar signature to a resource responder
+            method, taking (req, resp, params).
+        responder: The bound responder to wrap.
+
+    """
+
+    @wraps(responder)
+    def do_before(req, resp, **kwargs):
+        action(req, resp, kwargs)
+        responder(req, resp, **kwargs)
+
+    return do_before
+
+
+def _wrap_with_after(action, responder):
+    """Execute the given action function after a bound responder.
+
+    Args:
+        action: A function with a signature similar to a resource responder
+            method, taking (req, resp).
+        responder: The bound responder to wrap.
+
+    """
+
+    @wraps(responder)
+    def do_after(req, resp, **kwargs):
+        responder(req, resp, **kwargs)
+        action(req, resp)
+
+    return do_after
